@@ -15,7 +15,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import sys
-import subprocess
+import webbrowser
 from PyQt5 import QtCore, QtWidgets, QtGui
 import gpxviewer.plotviewer as plt
 import gpxviewer.gpxmodel as gpx
@@ -149,10 +149,10 @@ class GpxMainWindow(QtWidgets.QMainWindow):
       actNeglect.triggered.connect(self.neglectDistance)
       actReset = QtWidgets.QAction(self.tr('Reset'), self)
       actReset.triggered.connect(self.resetPoints)
-      actShowMap = QtWidgets.QAction(self.tr('Show on Google maps'), self)
-      actShowMap.triggered.connect(self.showGoogleMaps)
       actStyle = QtWidgets.QAction(QtGui.QIcon.fromTheme('configure', QtGui.QIcon(':/icons/configure.svg')), self.tr('Point style'), self)
       actStyle.triggered.connect(self.pointStyle)
+      actShowMap = QtWidgets.QAction(self.tr('Show on Google maps'), self)
+      actShowMap.triggered.connect(self.showGoogleMaps)
 
       menu = QtWidgets.QMenu(self)
       menu.addAction(actSkip)
@@ -164,9 +164,9 @@ class GpxMainWindow(QtWidgets.QMainWindow):
       menu.addSeparator()
       menu.addAction(actReset)
       menu.addSeparator()
-      menu.addAction(actShowMap)
-      menu.addSeparator()
       menu.addAction(actStyle)
+      menu.addSeparator()
+      menu.addAction(actShowMap)
       menu.popup(QtGui.QCursor.pos())
       event.accept()
 
@@ -287,15 +287,15 @@ class GpxMainWindow(QtWidgets.QMainWindow):
     self.setProjectChanged(True)
 
   def showGoogleMaps(self):
-    lat = TheDocument.wptmodel.index(self.ui.wptView.currentIndex().row(), gpx.LAT).data()
-    lon = TheDocument.wptmodel.index(self.ui.wptView.currentIndex().row(), gpx.LON).data()
-    subprocess.call('xdg-open ' + '"http://maps.google.com/maps?ll=' + lat + ',' + lon + '&t=h&q=' + lat + ',' + lon + '&z=17"', shell=True)
+    lat = self.ui.wptView.selectedIndexes()[gpx.LAT].data()
+    lon = self.ui.wptView.selectedIndexes()[gpx.LON].data()
+    webbrowser.open('http://maps.google.com/maps?ll=' + lat + ',' + lon + '&t=h&q=' + lat + ',' + lon + '&z=15')
 
   def pointStyle(self):
     style = {}
-    style.update(self.ui.wptView.selectionModel().selection().indexes()[0].data(gpx.MarkerRole))
-    style.update(self.ui.wptView.selectionModel().selection().indexes()[0].data(gpx.SplitLineRole))
-    style.update(self.ui.wptView.selectionModel().selection().indexes()[0].data(gpx.CaptionRole))
+    style.update(self.ui.wptView.selectedIndexes()[0].data(gpx.MarkerRole))
+    style.update(self.ui.wptView.selectedIndexes()[0].data(gpx.SplitLineRole))
+    style.update(self.ui.wptView.selectedIndexes()[0].data(gpx.CaptionRole))
     dlg = gpxviewer.pointconfigdialog.PointConfigDialog(self, style)
     if dlg.exec_() == QtWidgets.QDialog.Accepted:
       self.setProjectChanged(True)
@@ -515,8 +515,9 @@ class GpxMainWindow(QtWidgets.QMainWindow):
       TheConfig['ProfileStyle']['FillColor'] = str(dlg.style['FillColor'])
       TheConfig['ProfileStyle']['ProfileWidth'] = str(dlg.style['ProfileWidth'])
       TheConfig['ProfileStyle']['MinimumAltitude'] = str(dlg.style['MinimumAltitude'])
-      TheConfig['ProfileStyle']['MaximumAltitude'] = str(dlg.style['MaximumAltitude'])
+      TheConfig['ProfileStyle']['DistanceCoefficient'] = str(dlg.style['DistanceCoefficient'])
       TheConfig['ProfileStyle']['TimeZoneOffset'] = str(dlg.style['TimeZoneOffset'])
+      TheDocument.gpxparser.updateDistance()
 
   def showWarning(self, title, text):
     QtWidgets.QMessageBox.warning(self, title, text)
